@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: alddefs.h,v 1.1.1.1 2003/08/14 03:28:50 cosine Exp $
+ * $Id: alddefs.h,v 1.1.1.1 2004/04/26 00:41:12 pa33 Exp $
  */
 
 #ifndef INCLUDED_alddefs_h
@@ -24,10 +24,4 @@
  */
 #define ALD_PROMPT   "ald> "
 
-/*
- * Endian types for the PlatformEndian variable
- */
-#define ENDIANTYPE_LITTLE   0
-#define ENDIANTYPE_BIG      1
-
 #endif /* INCLUDED_alddefs_h */
