@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: command.h,v 1.1.1.1 2003/08/14 03:28:50 cosine Exp $
+ * $Id: command.h,v 1.4 2004/10/10 05:29:48 pa33 Exp $
  */
 
 #ifndef INCLUDED_command_h
@@ -39,12 +39,11 @@ struct commandWorkspace
  * Various command bitmasks
  */
 #define C_ALIAS              (1 << 0) /* command is an alias for another */
-#define C_CURSES             (1 << 1) /* curses-mode only command */
-#define C_PROCESS            (1 << 2) /* command requires a debugee process */
-#define C_FILELOADED         (1 << 3) /* needs a file loaded (via "load") */
-#define C_AMBIGUOUS          (1 << 4) /* command is ambiguous */
-#define C_PTRACE             (1 << 5) /* command uses ptrace call */
-#define C_PROCESS_RUNNING    (1 << 6) /* command requires running process */
+#define C_PROCESS            (1 << 1) /* command requires a debugee process */
+#define C_FILELOADED         (1 << 2) /* needs a file loaded (via "load") */
+#define C_AMBIGUOUS          (1 << 3) /* command is ambiguous */
+#define C_PTRACE             (1 << 4) /* command uses ptrace call */
+#define C_PROCESS_RUNNING    (1 << 5) /* command requires running process */
 
 /*
  * Prototypes
@@ -59,12 +58,12 @@ struct Command *FindCommand(struct Command *cmdlist, char *name,
 
 int c_attach(struct aldWorkspace *ws, int ac, char **av);
 int c_break(struct aldWorkspace *ws, int ac, char **av);
-int c_clear(struct aldWorkspace *ws, int ac, char **av);
 int c_continue(struct aldWorkspace *ws, int ac, char **av);
-int c_delete(struct aldWorkspace *ws, int ac, char **av);
+int c_dbreak(struct aldWorkspace *ws, int ac, char **av);
 int c_detach(struct aldWorkspace *ws, int ac, char **av);
 int c_disable(struct aldWorkspace *ws, int ac, char **av);
 int c_disassemble(struct aldWorkspace *ws, int ac, char **av);
+int c_display(struct aldWorkspace *ws, int ac, char **av);
 int c_enable(struct aldWorkspace *ws, int ac, char **av);
 int c_enter(struct aldWorkspace *ws, int ac, char **av);
 int c_examine(struct aldWorkspace *ws, int ac, char **av);
@@ -72,6 +71,7 @@ int c_file(struct aldWorkspace *ws, int ac, char **av);
 int c_help(struct aldWorkspace *ws, int ac, char **av);
 int c_ignore(struct aldWorkspace *ws, int ac, char **av);
 int c_lbreak(struct aldWorkspace *ws, int ac, char **av);
+int c_ldisplay(struct aldWorkspace *ws, int ac, char **av);
 int c_load(struct aldWorkspace *ws, int ac, char **av);
 int c_next(struct aldWorkspace *ws, int ac, char **av);
 int c_quit(struct aldWorkspace *ws, int ac, char **av);
@@ -80,8 +80,13 @@ int c_run(struct aldWorkspace *ws, int ac, char **av);
 int c_set(struct aldWorkspace *ws, int ac, char **av);
 int c_step(struct aldWorkspace *ws, int ac, char **av);
 int c_tbreak(struct aldWorkspace *ws, int ac, char **av);
+int c_undisplay(struct aldWorkspace *ws, int ac, char **av);
 int c_unload(struct aldWorkspace *ws, int ac, char **av);
-int c_window(struct aldWorkspace *ws, int ac, char **av);
-int c_write(struct aldWorkspace *ws, int ac, char **av);
+
+/*
+ * External declarations
+ */
+
+extern jmp_buf *CmdParserEnvPtr;
 
 #endif /* INCLUDED_command_h */
