@@ -8,30 +8,35 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: main.h,v 1.1.1.1 2003/08/14 03:28:50 cosine Exp $
+ * $Id: main.h,v 1.3 2004/10/10 05:29:48 pa33 Exp $
  */
 
 #ifndef INCLUDED_main_h
 #define INCLUDED_main_h
 
 #include "command.h"
+
+#ifndef INCLUDED_print_h
 #include "print.h"
+#define INCLUDED_print_h
+#endif
+
 #include "rc.h"
 #include "terminal.h"
 
-#ifndef INCLUDED_libDebug_h
+#ifndef INCLUDED_libDebug_libDebug_h
 #include "libDebug.h"
-#define INCLUDED_libDebug_h
+#define INCLUDED_libDebug_libDebug_h
 #endif
 
-#ifndef INCLUDED_libDASM_h
+#ifndef INCLUDED_libDASM_libDASM_h
 #include "libDASM.h"
-#define INCLUDED_libDASM_h
+#define INCLUDED_libDASM_libDASM_h
 #endif
 
-#ifndef INCLUDED_libOFF_h
+#ifndef INCLUDED_libOFF_libOFF_h
 #include "libOFF.h"         /* struct offWorkspace */
-#define INCLUDED_libOFF_h
+#define INCLUDED_libOFF_libOFF_h
 #endif
 
 struct aldWorkspace
@@ -64,8 +69,29 @@ struct aldWorkspace
   unsigned long nextInstruction;     /* next instruction to disassemble */
   unsigned int currentSectionStart;  /* start of current section */
 
+  /*
+   * This list contains pointers to memory which need to
+   * be freed in case the path of execution takes an
+   * unexpected turn. For example, in the "examine" command,
+   * memory is allocated for the buffer which contains the
+   * memory dump. If the user stops looking at the memory output
+   * before it completes (either ^C or hitting 'q' during the
+   * pause-print screen), that memory won't be freed normally
+   * by c_examine, since a longjmp() is performed back to
+   * procCommand(). Therefore, when procCommand() notices that
+   * longjmp() was used, it will free any items in this list.
+   */
+  struct genericList *toBeFreed;
+
+  /*
+   * This list contains pointers to address ranges which we
+   * will dump from memory after each single step. See the
+   * "help display" info
+   */
+  struct genericList *stepDisplayList;
+  unsigned int stepDisplayNum;
+
   struct commandWorkspace *commandWorkspace_p;
-  struct loadWorkspace *loadWorkspace_p;
   struct printWorkspace *printWorkspace_p;
   struct rcWorkspace *rcWorkspace_p;
   struct terminalWorkspace *terminalWorkspace_p;
@@ -95,14 +121,4 @@ struct aldWorkspace *initALD(int argc, char *argv[]);
 void termALD(struct aldWorkspace *ws);
 int procALD(struct aldWorkspace *ws);
 
-/*
- * External declarations
- */
-
-extern struct aldWorkspace *mainWorkspace_p;
-
-extern int ModeConsole;
-extern int ModeCurses;
-extern int PlatformEndian;
-
 #endif /* INCLUDED_main_h */
