@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: memory.h,v 1.1.1.1 2003/08/14 03:28:50 cosine Exp $
+ * $Id: memory.h,v 1.2 2004/07/21 16:36:06 pa33 Exp $
  */
 
 #ifndef INCLUDED_memory_h
@@ -45,7 +45,7 @@ struct MemFormat
 /*
  * Prototypes
  */
-long GetElementSize(char *str);
+unsigned long GetElementSize(char *str);
 void OutputMemory(struct aldWorkspace *ws, unsigned char *buf, unsigned long start,
                   long bytes, long size, unsigned char output);
 
