@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: msg.h,v 1.1.1.1 2003/08/14 03:28:50 cosine Exp $
+ * $Id: msg.h,v 1.1.1.1 2004/04/26 00:41:11 pa33 Exp $
  */
 
 #ifndef INCLUDED_msg_h
@@ -28,8 +28,10 @@
 #define MSG_PTERR           "Error in ptrace(): %s"
 #define MSG_BKPTENCOUNTERED "Breakpoint %d encountered at 0x%08lX"
 #define MSG_GOTSIGNAL       "\nProgram received signal %s (%s)\nLocation: 0x%08lX"
+#define MSG_GOTUNKNOWNSIG   "\nProgram received unknown signal %d\nLocation: 0x%08lX"
 #define MSG_NOACCESS        "Unable to access memory at location 0x%08X: %s"
 #define MSG_NOPROCESS       "No process is currently being debugged"
 #define MSG_PROGTERMSIG     "Program terminated with signal %s (%s)"
+#define MSG_PROGTERMUNKNOWNSIG "Program terminated with unknown signal %d"
 
 #endif /* INCLUDED_msg_h */
