@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: print.h,v 1.1.1.1 2003/08/14 03:28:50 cosine Exp $
+ * $Id: print.h,v 1.1.1.1 2004/04/26 00:41:12 pa33 Exp $
  */
 
 #ifndef INCLUDED_print_h
@@ -29,11 +29,6 @@
 #define INCLUDED_alddefs_h
 #endif
 
-#ifndef INCLUDED_defs_h
-#include "defs.h"          /* USE_CURSES */
-#define INCLUDED_defs_h
-#endif
-
 struct printWorkspace
 {
   int PausePrint;              /* print bursts will be paused after each pageful */
@@ -64,7 +59,7 @@ void startPrintBurst(struct printWorkspace *ws);
 void endPrintBurst(struct printWorkspace *ws);
 void Print(struct aldWorkspace *main_p, int flags, const char *format, ...);
 void RawPrint(struct aldWorkspace *main_p, int flags, const char *format, ...);
-void PrintWindow(struct aldWorkspace *main_p, int raw, int flags,
+void PrintWindow(struct aldWorkspace *main_p, int raw,
                  const char *format, va_list args);
 
 #endif /* INCLUDED_print_h */
