@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this library is distributed.
  *
- * $Id: args-x86.h,v 1.1.1.1 2003/08/14 03:28:50 cosine Exp $
+ * $Id: args-x86.h,v 1.2 2004/08/31 02:24:50 pa33 Exp $
  */
 
 #ifndef INCLUDED_args_x86_h
@@ -28,7 +28,9 @@
  * Prototypes
  */
 
-int x86constructArguments(struct disasmWorkspace *ws, unsigned char **data,
-                          struct x86matchInfo *ptr, char *outbuf);
+int x86constructArguments(struct disasmWorkspace *ws,
+                          unsigned char **data,
+                          struct x86matchInfo *ptr, char *outbuf,
+                          unsigned int address);
 
 #endif /* INCLUDED_args_x86_h */
