@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this library is distributed.
  *
- * $Id: asm-x86.h,v 1.4 2003/08/26 00:09:03 cosine Exp $
+ * $Id: asm-x86.h,v 1.1.1.1 2004/04/26 00:40:23 pa33 Exp $
  */
 
 #ifndef INCLUDED_asm_x86_h
@@ -33,8 +33,18 @@ struct instructionInfo
 
   struct immediateInfo immInfo;  /* numerical constant information */
   int hasImmed;                  /* has an immediate operand? */
+
+  unsigned int flags;            /* instruction flags (X86INS_xxx) */
 };
 
+/*
+ * Instruction flags
+ */
+
+#define X86INS_BITS8      (1 << 0)  /* 8 bit instruction */
+#define X86INS_BITS16     (1 << 1)  /* 16 bit instruction */
+#define X86INS_BITS32     (1 << 2)  /* 32 bit instruction */
+
 /*
  * Prototypes
  */
