@@ -8,13 +8,14 @@
  * do so under the terms of the GNU General Public License under which
  * this library is distributed.
  *
- * $Id: args-x86.c,v 1.4 2003/08/16 20:43:29 cosine Exp $
+ * $Id: args-x86.c,v 1.3 2004/09/02 00:11:59 pa33 Exp $
  *
  * This module is used by the disassembler to construct the argument
  * string for a particular opcode.
  */
 
 #include <stdio.h>
+#include <string.h>
 #include <assert.h>
 
 #include "args-x86.h"
@@ -103,10 +104,16 @@ static char *x86SegmentRegisters[] = {
 x86constructArguments()
   Construct the correct arguments for the instruction 'ptr'.
 
-Inputs: ws     - disasm workspace
-        data   - data buffer containing instruction we are disassembling
-        ptr    - instruction matching 'data'
-        outbuf - where to store arguments
+Inputs: ws      - disasm workspace
+        data    - data buffer containing instruction we are
+                  disassembling
+        ptr     - instruction matching 'data'
+        outbuf  - where to store arguments
+        address - address of this instruction in the file or memory
+                  we are currently disassembling; when given,
+                  relative addresses (such as in a CALL or JMP)
+                  will be added to this address to calculate
+                  an exact target address.
 
 Return: 1 upon success
         0 upon failure (error message goes in outbuf)
@@ -120,16 +127,46 @@ Side effects: On success, outbuf will contain instruction name and arguments
 
 int
 x86constructArguments(struct disasmWorkspace *ws, unsigned char **data,
-                      struct x86matchInfo *ptr, char *outbuf)
+                      struct x86matchInfo *ptr, char *outbuf,
+                      unsigned int address)
 
 {
   int ii;                   /* looping */
   struct x86OpCode *opPtr;  /* opcode pointer */
   char tmpbuf[MAXLINE];     /* temporary buffer */
   char *origout;            /* original outbuf */
+  long bias;                /* eip relative address bias */
 
   assert(data && *data && ptr && outbuf);
 
+  /*
+   * bias is initialized to the 2's compliment of the instruction's
+   * actual address in the buffer.  We do this to compute the
+   * size of the instruction by adding the new value of *data.
+   * The resulting equation is this:
+   *
+   * bias = NEW_data_addr - OLD_data_addr
+   *
+   * which is precisely what we want.
+   *
+   * Note the [-1] subscript of the character array reference is
+   * to compensate for the fact that the instruction's opcode has
+   * already been "fetched" by the disassembly engine.
+   *
+   * --2004aug30 saf2
+   *
+   * The purpose of this is for relative operands which are
+   * defined relative to the instruction after the current
+   * instruction. In order to compute an exact address, we
+   * need to know the size of the current opcode. This bias
+   * variable is set to that size in the section below on
+   * relative operands.
+   *
+   * -- Patrick Alken
+   */
+
+  bias = -((unsigned long)(&((*data)[-1])));
+
   opPtr = ptr->opPtr;
   origout = outbuf;
 
@@ -251,7 +288,26 @@ x86constructArguments(struct disasmWorkspace *ws, unsigned char **data,
         return (0);
       }
 
+      /*
+       * Note: this code was contributed by Samuel Falvo II
+       * <kc5tja =at= arrl net>
+       */
+      bias += (unsigned long) (*data);
+      if ((unsigned char) *(opPtr->mcode) == 0x0F)
+      {
+        /* two-byte branch */
+        bias++;
+      }
+
       outbuf += sprintf(outbuf, "+0x%lx", value);
+
+      /*
+       * Store the exact target address in ws->effectiveAddress
+       * so that the calling program can use it to look up
+       * symbols/functions corresponding to this relative
+       * address.
+       */
+      ws->effectiveAddress = address + value + bias;
     } /* if (opPtr->operands[ii] & RELATIVE) */
     else if (opPtr->operands[ii] & SEG16)
     {
@@ -307,6 +363,28 @@ x86constructArguments(struct disasmWorkspace *ws, unsigned char **data,
                         "%s",
                         x86SegmentRegisters[ptr->msinfo.reg]);
     } /* if (opPtr->operands[ii] & REG_SR) */
+    else if (opPtr->operands[ii] & REG_CONTROL)
+    {
+      /*
+       * According to IAS, Vol 2. the REG field of the ModR/M
+       * byte specifies the control register
+       */
+
+      outbuf += sprintf(outbuf,
+                        "%s",
+                        x86RegistersDASM[R_CR0 + ptr->msinfo.reg].name);
+    } /* if (opPtr->operands[ii] & REG_CONTROL) */
+    else if (opPtr->operands[ii] & REG_DEBUG)
+    {
+      /*
+       * According to IAS, Vol 2. the REG field of the ModR/M
+       * byte specifies the debug register
+       */
+
+      outbuf += sprintf(outbuf,
+                        "%s",
+                        x86RegistersDASM[R_DR0 + ptr->msinfo.reg].name);
+    } /* if (opPtr->operands[ii] & REG_DEBUG) */
     else if (opPtr->operands[ii] & MEMOFFS)
     {
       int ret;
@@ -383,7 +461,10 @@ x86operandRegister(struct x86matchInfo *ptr, int opnum, char *errstr)
       return (0);
     }
 
-    return (x86RegistersDASM[opPtr->opinfo[opnum]].name);
+    if (opPtr->opinfo[opnum] == MODFIELD_RM)
+      return (x86getModRegister(ptr->msinfo.rm, operand));
+    else
+      return (x86RegistersDASM[opPtr->opinfo[opnum]].name);
   }
 
   if (opPtr->digit == REGRM)
