@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this library is distributed.
  *
- * $Id: disasm-x86.c,v 1.2 2003/08/16 20:43:29 cosine Exp $
+ * $Id: disasm-x86.c,v 1.3 2004/09/02 00:11:59 pa33 Exp $
  */
 
 #include <stdio.h>
@@ -33,9 +33,13 @@ static long x86findOpCode(struct disasmWorkspace *ws, unsigned char *data,
 x86procDisasm()
   Disassemble one instruction
 
-Inputs: ws     - disasm workspace
-        data   - data to disassemble
-        outbuf - buffer to store result
+Inputs: ws      - disasm workspace
+        data    - data to disassemble
+        outbuf  - buffer to store result
+        address - address of this opcode in the file or memory;
+                  when given, relative addresses such as in a
+                  CALL opcode will be added to this to compute
+                  an exact target address.
 
 Return: number of bytes disassembled, or if an error occurs -1 and
         an error message goes in outbuf
@@ -43,7 +47,7 @@ Return: number of bytes disassembled, or if an error occurs -1 and
 
 long
 x86procDisasm(struct disasmWorkspace *ws, unsigned char *data,
-              char *outbuf)
+              char *outbuf, unsigned int address)
 
 {
   unsigned char *origdata;
@@ -57,6 +61,7 @@ x86procDisasm(struct disasmWorkspace *ws, unsigned char *data,
 
   memset(&match, '\0', sizeof(struct x86matchInfo));
   ws->prefixFlags = 0;
+  ws->effectiveAddress = 0;
 
   bytesMatched = x86findOpCode(ws, data, outbuf, &match);
 
@@ -80,7 +85,8 @@ x86procDisasm(struct disasmWorkspace *ws, unsigned char *data,
   ret = x86constructArguments(ws,
                               (unsigned char **) &data,
                               &match,
-                              outbuf);
+                              outbuf,
+                              address);
 
   if (ret)
     return (data - origdata);
