@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: assemble.h,v 1.4 2003/08/26 00:09:03 cosine Exp $
+ * $Id: assemble.h,v 1.2 2004/10/09 17:41:50 pa33 Exp $
  */
 
 #ifndef INCLUDED_libDASM_assemble_h
@@ -19,9 +19,9 @@
 #define INCLUDED_libDASM_h
 #endif
 
-#ifndef INCLUDED_cfgDASM_h
-#include "cfgDASM.h"           /* INTEL86 */
-#define INCLUDED_cfgDASM_h
+#ifndef INCLUDED_api_cfgDASM_h
+#include "api_cfgDASM.h"           /* INTEL86 */
+#define INCLUDED_api_cfgDASM_h
 #endif
 
 struct asmWorkspace
