@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: disassemble.h,v 1.1.1.1 2003/08/14 03:28:50 cosine Exp $
+ * $Id: disassemble.h,v 1.4 2004/10/09 17:41:50 pa33 Exp $
  */
 
 #ifndef INCLUDED_libDASM_disassemble_h
@@ -19,9 +19,9 @@
 #define INCLUDED_libDASM_h
 #endif
 
-#ifndef INCLUDED_cfgDASM_h
-#include "cfgDASM.h"             /* INTEL86 */
-#define INCLUDED_cfgDASM_h
+#ifndef INCLUDED_api_cfgDASM_h
+#include "api_cfgDASM.h"             /* INTEL86 */
+#define INCLUDED_api_cfgDASM_h
 #endif
 
 struct disasmWorkspace
@@ -30,6 +30,15 @@ struct disasmWorkspace
 
   unsigned int prefixFlags;      /* PX_xxx */
   int segmentOverride;           /* segment override register, if any */
+
+  /*
+   * For relative operands, store the exact target address here,
+   * so that the calling program can look up symbols/functions
+   * corresponding to the relative address. This variable will
+   * always be 0 when returning from a disassembly call unless
+   * there was a relative operand.
+   */
+  unsigned int effectiveAddress;
 };
 
 /*
@@ -53,6 +62,6 @@ struct disasmWorkspace *initDisasm(unsigned int flags);
 void termDisasm(struct disasmWorkspace *ws);
 void flagsDisasm(struct disasmWorkspace *ws, unsigned int flags);
 long procDisasm(struct disasmWorkspace *ws, unsigned char *data,
-                char *outbuf);
+                char *outbuf, unsigned int address);
 
 #endif /* INCLUDED_libDASM_disassemble_h */
