@@ -1,14 +1,18 @@
 /*
  * libDASM
  *
- * Copyright (C) 2000-2003 Patrick Alken
+ * Copyright (C) 2000-2004 Patrick Alken
  * This library comes with absolutely NO WARRANTY
  *
  * Should you choose to use and/or modify this source code, please
  * do so under the terms of the GNU General Public License under which
  * this library is distributed.
  *
- * $Id: version.c,v 1.1.1.1 2003/08/14 03:28:51 cosine Exp $
+ * $Id: version.c,v 1.3 2004/10/09 23:08:01 pa33 Exp $
  */
 
-char libDASMVersion[] = "0.1.0";
+#ifdef VERSION
+char libDASMVersion[] = VERSION;
+#else
+char libDASMVersion[] = "";
+#endif
