@@ -15,7 +15,14 @@
 /* opcode buffer */
 
 char buf[] = {
-  0x0F, 0x22, 0x33,
+  0xE8, 0x78, 0x45, 0x23, 0x10,
+  0x0F, 0x20, 0xD8,
+  0x0F, 0x21, 0xF3,
+  0x0F, 0x21, 0xFC,
+  0x0F, 0x21, 0xD3,
+  0x0F, 0x23, 0xF3,
+  0x0F, 0x23, 0xFC,
+  0x0F, 0x23, 0xD3,
 };
 
 int
