@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: sub-x86.h,v 1.1.1.1 2003/08/14 03:28:51 cosine Exp $
+ * $Id: sub-x86.h,v 1.2 2004/09/11 05:17:15 pa33 Exp $
  */
 
 #ifndef INCLUDED_sub_x86_h
@@ -24,6 +24,6 @@ struct OpSub
 /*
  * Prototypes
  */
-int IsSubroutine(char *buf);
+int IsSubroutine(unsigned char *buf);
 
 #endif /* INCLUDED_sub_x86_h */
