@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: trace-x86.h,v 1.1.1.1 2003/08/14 03:28:51 cosine Exp $
+ * $Id: trace-x86.h,v 1.3 2004/09/11 05:17:15 pa33 Exp $
  */
 
 #ifndef INCLUDED_trace_x86_h
@@ -24,7 +24,7 @@
  */
 #define BRKPT_INSN    0xCC
 
-#if defined(OS_FREEBSD) || defined(OS_OPENBSD)
+#if defined(OS_BSD) /* FreeBSD, OpenBSD, NetBSD */
 
 /*
  * Continuation address
@@ -69,8 +69,8 @@ int x86killDebug(struct debugWorkspace *ws);
 int x86saveBreakpoint(struct debugWorkspace *ws, struct Breakpoint *bptr);
 int x86enableBreakpoint(struct debugWorkspace *ws, struct Breakpoint *bptr);
 int x86disableBreakpoint(struct debugWorkspace *ws, struct Breakpoint *bptr);
-long x86dumpMemoryDebug(struct debugWorkspace *ws, char **buf, unsigned long start,
-                        long bytes);
+long x86dumpMemoryDebug(struct debugWorkspace *ws, unsigned char **buf,
+                        unsigned long start, unsigned long bytes);
 int x86setMemoryDebug(struct debugWorkspace *ws, unsigned long address,
                       unsigned long value);
 
