@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this library is distributed.
  *
- * $Id: regs-x86.c,v 1.5 2003/09/07 17:52:08 cosine Exp $
+ * $Id: regs-x86.c,v 1.2 2004/10/09 17:34:15 pa33 Exp $
  *
  * This module contains routines dealing with x86 registers which are common to
  * all operating systems.
@@ -275,7 +275,7 @@ x86printRegistersDebug(struct debugWorkspace *ws, int regindex,
        * Print out the general registers first
        */
       ws->regInfo.flags |= DB_RI_GENERAL;
-      ws->regInfo.size = 8;
+
 
       for (ii = 0; ii < REG_ENDGENERAL; ++ii)
       {
@@ -284,10 +284,13 @@ x86printRegistersDebug(struct debugWorkspace *ws, int regindex,
         if (rptr->flags & R_NODISPLAY)
           continue;
 
+
         size = x86readRegisterDebug(ws,
                                     rptr,
                                     &regVal);
 
+        ws->regInfo.size = size;
+
         ws->regInfo.value = regVal.lvalue;
         strcpy(ws->regInfo.name, rptr->name);
 
@@ -330,7 +333,7 @@ x86printRegistersDebug(struct debugWorkspace *ws, int regindex,
        */
 
       ws->regInfo.flags |= DB_RI_FPU_DATA;
-      ws->regInfo.size = 4;
+      ws->regInfo.size = 2;
 
       for (ii = 0; ii < FPU_NUM_DATA_REGS; ++ii)
       {
@@ -355,7 +358,7 @@ x86printRegistersDebug(struct debugWorkspace *ws, int regindex,
 
       ws->regInfo.flags &= ~DB_RI_FPU_DATA;
 
-      ws->regInfo.size = 4;
+      ws->regInfo.size = 2;
 
       strcpy(ws->regInfo.name, x86Registers[REG_FCTRL].name);
       ws->regInfo.value = (unsigned long) fpuState->fctrl;
@@ -369,27 +372,27 @@ x86printRegistersDebug(struct debugWorkspace *ws, int regindex,
       ws->regInfo.value = (unsigned long) fpuState->ftag;
       (*callback)(&(ws->regInfo), callbackArgs);
 
-      ws->regInfo.size = 4;
+      ws->regInfo.size = 2;
       strcpy(ws->regInfo.name, x86Registers[REG_FCS].name);
       ws->regInfo.value = fpuState->fcs;
       (*callback)(&(ws->regInfo), callbackArgs);
 
-      ws->regInfo.size = 8;
+      ws->regInfo.size = 4;
       strcpy(ws->regInfo.name, x86Registers[REG_FIP].name);
       ws->regInfo.value = fpuState->fip;
       (*callback)(&(ws->regInfo), callbackArgs);
 
-      ws->regInfo.size = 2;
+      ws->regInfo.size = 1;
       strcpy(ws->regInfo.name, x86Registers[REG_FOSEG].name);
       ws->regInfo.value = fpuState->foseg;
       (*callback)(&(ws->regInfo), callbackArgs);
 
-      ws->regInfo.size = 8;
+      ws->regInfo.size = 4;
       strcpy(ws->regInfo.name, x86Registers[REG_FOOFF].name);
       ws->regInfo.value = fpuState->fooff;
       (*callback)(&(ws->regInfo), callbackArgs);
 
-      ws->regInfo.size = 4;
+      ws->regInfo.size = 2;
       strcpy(ws->regInfo.name, x86Registers[REG_FOPCODE].name);
       ws->regInfo.value = fpuState->fopcode;
       (*callback)(&(ws->regInfo), callbackArgs);
@@ -420,7 +423,7 @@ x86printRegistersDebug(struct debugWorkspace *ws, int regindex,
         return (0);
 
       ws->regInfo.flags |= DB_RI_MMX;
-      ws->regInfo.size = 8;
+      ws->regInfo.size = 4;
 
       for (ii = 0; ii < MMX_NUM_REGS; ++ii)
       {
@@ -466,7 +469,6 @@ x86printRegistersDebug(struct debugWorkspace *ws, int regindex,
     }
 
     regvalue = (regVal.lvalue >> shr) & 0xFF;
-    size = 2;
   }
   else if (rptr->flags & R_BITS16)
   {
@@ -479,12 +481,10 @@ x86printRegistersDebug(struct debugWorkspace *ws, int regindex,
     }
 
     regvalue = (regVal.lvalue >> shr) & 0xFFFF;
-    size = 4;
   }
   else if (rptr->flags & R_BITS32)
   {
     regvalue = regVal.lvalue;
-    size = 8;
   }
   else if ((rptr->flags & R_BITS64) && (rptr->flags & R_MMX))
   {
