@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this library is distributed.
  *
- * $Id: sub-x86.c,v 1.1.1.1 2003/08/14 03:28:51 cosine Exp $
+ * $Id: sub-x86.c,v 1.2 2004/09/11 05:17:16 pa33 Exp $
  */
 
 #include "sub-x86.h"
@@ -32,13 +32,13 @@ Return: 0 if it is not a subroutine, or the number of bytes in the
 */
 
 int
-IsSubroutine(char *buf)
+IsSubroutine(unsigned char *buf)
 
 {
   unsigned char first;
   struct OpSub *optr;
 
-  first = (unsigned char) *buf++;
+  first = *buf++;
   for (optr = SubOpcodes; optr->oplen; ++optr)
   {
     if (first == optr->byte)
@@ -51,7 +51,7 @@ IsSubroutine(char *buf)
          * This opcode expects a ModR/M digit - make sure it
          * matches the next byte of 'buf'
          */
-        reg = ((unsigned char) *buf >> 3) & 0x07;
+        reg = (*buf >> 3) & 0x07;
         if (reg != optr->digit)
           continue; /* bad match */
       }
