@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this library is distributed.
  *
- * $Id: trace-x86.c,v 1.2 2003/08/27 20:38:15 cosine Exp $
+ * $Id: trace-x86.c,v 1.6 2004/10/09 17:34:15 pa33 Exp $
  */
 
 #include <stdio.h>
@@ -28,7 +28,6 @@
  */
 #include "args.h"
 #include "break.h"
-#include "configDb.h"
 #include "libDebug.h"
 
 static int x86GetDebugProcessStatus(struct debugWorkspace *ws,
@@ -181,7 +180,8 @@ Return: 0 if something goes wrong
 */
 
 static int
-x86GetDebugProcessStatus(struct debugWorkspace *ws, int ptfunc, int waitval, int *data)
+x86GetDebugProcessStatus(struct debugWorkspace *ws, int ptfunc,
+                         int waitval, int *data)
 
 {
   int sig;
@@ -424,6 +424,7 @@ x86DoContinue(struct debugWorkspace *ws, int *data)
   int waitval;
   int ret;
   int err;
+  pid_t wret;
 
   assert(ws->pid != NOPID);
 
@@ -454,13 +455,15 @@ x86DoContinue(struct debugWorkspace *ws, int *data)
      */
     enableBreakpoints(ws);
 
+    /*fprintf(stderr, "lastsig = %d\n", ws->lastSignal);*/
     if (ptrace(PT_CONTINUE, ws->pid, CONTADDR, ws->lastSignal) != 0)
       return (0); /* something went wrong */
 
     /*
      * Wait for child to stop
      */
-    wait(&waitval);
+    wret = wait(&waitval);
+    /*fprintf(stderr, "wret = %d\n", wret);*/
 
     /*
      * Disable all breakpoints
@@ -587,10 +590,10 @@ x86stepOverDebug(struct debugWorkspace *ws, int num, int *data)
 
 {
   int ii,
-      dret,           /* return value from dump memory routine */
-      pret;           /* return value from a ptrace function */
-  unsigned long slen; /* length of subroutine call opcode */
-  char *opbuf;        /* contains potential call opcode */
+      dret,             /* return value from dump memory routine */
+      pret;             /* return value from a ptrace function */
+  unsigned long slen;   /* length of subroutine call opcode */
+  unsigned char *opbuf; /* contains potential call opcode */
 
   assert(num > 0);
 
@@ -968,17 +971,16 @@ Side effects: space is allocated for 'buf', so it must be freed by
 */
 
 long
-x86dumpMemoryDebug(struct debugWorkspace *ws, char **buf, unsigned long start, long bytes)
+x86dumpMemoryDebug(struct debugWorkspace *ws, unsigned char **buf,
+                   unsigned long start, unsigned long bytes)
 
 {
   int wordval;
   unsigned long addr, /* current address we are examining */
                 end;  /* last address to examine */
-  char *bufptr;
+  unsigned char *bufptr;
   long ret;           /* return value */
 
-  assert(bytes > 0);
-
   if (ws->pid == NOPID)
   {
     if (x86execDebug(ws) == 0)
@@ -986,10 +988,19 @@ x86dumpMemoryDebug(struct debugWorkspace *ws, char **buf, unsigned long start, l
   }
 
   addr = start;
+
   end = start + bytes;
+  if (end < start)
+    return (0); /* integer overflow */
+
+  if ((bytes + 1) == 0)
+    return (0); /* integer overflow */
 
   *buf = (char *) malloc(bytes + 1);
-  bufptr = *buf;
+  if (*buf == NULL)
+    return (0);
+
+  bufptr = (unsigned char *) *buf;
 
   ret = 0;
 
@@ -1010,7 +1021,7 @@ x86dumpMemoryDebug(struct debugWorkspace *ws, char **buf, unsigned long start, l
      * the address 'addr' last, so anding with 0xff will separate
      * that byte.
      */
-    *bufptr++ = (char) (wordval & 0xff);
+    *bufptr++ = (unsigned char) (wordval & 0xff);
 
     ++addr;
     ++ret;
