@@ -8,11 +8,11 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: args.h,v 1.1.1.1 2003/08/14 03:28:51 cosine Exp $
+ * $Id: args.h,v 1.1.1.1 2004/04/26 00:41:11 pa33 Exp $
  */
 
-#ifndef INCLUDED_args_h
-#define INCLUDED_args_h
+#ifndef INCLUDED_libDebug_args_h
+#define INCLUDED_libDebug_args_h
 
 /*
  * Prototypes
@@ -20,4 +20,4 @@
 
 int SplitArgs(char *buffer, char ***array);
 
-#endif /* INCLUDED_args_h */
+#endif /* INCLUDED_libDebug_args_h */
