@@ -8,11 +8,11 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: break.h,v 1.1.1.1 2003/08/14 03:28:51 cosine Exp $
+ * $Id: break.h,v 1.1.1.1 2004/04/26 00:41:11 pa33 Exp $
  */
 
-#ifndef INCLUDED_break_h
-#define INCLUDED_break_h
+#ifndef INCLUDED_libDebug_break_h
+#define INCLUDED_libDebug_break_h
 
 struct Breakpoint
 {
@@ -64,4 +64,4 @@ void deactivateBreakpoint(struct debugWorkspace *ws,struct Breakpoint *ptr);
 void activateBreakpoint(struct debugWorkspace *ws, struct Breakpoint *ptr);
 void setIgnoreCount(struct Breakpoint *ptr, long count);
 
-#endif /* INCLUDED_break_h */
+#endif /* INCLUDED_libDebug_break_h */
