@@ -8,30 +8,35 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: libDebug.h,v 1.1.1.1 2003/08/14 03:28:51 cosine Exp $
+ * $Id: libDebug.h,v 1.4 2004/10/09 17:34:15 pa33 Exp $
  */
 
-#ifndef INCLUDED_libDebug_h
-#define INCLUDED_libDebug_h
+#ifndef INCLUDED_libDebug_libDebug_h
+#define INCLUDED_libDebug_libDebug_h
 
 #ifndef INCLUDED_sys_types_h
 #include <sys/types.h>          /* pid_t */
 #define INCLUDED_sys_types_h
 #endif
 
-#ifndef INCLUDED_configDb_h
-#include "configDb.h"
-#define INCLUDED_configDb_h
+#ifndef INCLUDED_api_cfgDebug_h
+#include "api_cfgDebug.h"
+#define INCLUDED_api_cfgDebug_h
 #endif
 
-#ifndef INCLUDED_args_h
+#ifndef INCLUDED_libDebug_args_h
 #include "args.h"
-#define INCLUDED_args_h
+#define INCLUDED_libDebug_args_h
 #endif
 
-#ifndef INCLUDED_break_h
+#ifndef INCLUDED_libDebug_break_h
 #include "break.h"
-#define INCLUDED_break_h
+#define INCLUDED_libDebug_break_h
+#endif
+
+#ifndef INCLUDED_libDebug_version_h
+#include "version.h"
+#define INCLUDED_libDebug_version_h
 #endif
 
 /*
@@ -201,10 +206,10 @@ int findRegisterDebug(struct debugWorkspace *ws, char *name);
 int setRegisterDebug(struct debugWorkspace *ws, int regindex, char *value);
 long readRegisterDebug(struct debugWorkspace *ws, int regindex);
 int getFlagsDebug(struct debugWorkspace *ws, char *flags);
-long dumpMemoryDebug(struct debugWorkspace *ws, char **buf, unsigned long start,
-                     long bytes);
+long dumpMemoryDebug(struct debugWorkspace *ws, unsigned char **buf,
+                     unsigned long start, unsigned long bytes);
 int setMemoryDebug(struct debugWorkspace *ws, unsigned long address, unsigned long value);
 int attachDebug(struct debugWorkspace *ws, int pid);
 int detachDebug(struct debugWorkspace *ws);
 
-#endif /* INCLUDED_libDebug_h */
+#endif /* INCLUDED_libDebug_libDebug_h */
