@@ -1,14 +1,14 @@
 /*
  * libDebug
  *
- * Copyright (C) 2000 Patrick Alken
+ * Copyright (C) 2000-2003 Patrick Alken
  * This library comes with absolutely NO WARRANTY
  *
  * Should you choose to use and/or modify this source code, please
  * do so under the terms of the GNU General Public License under which
  * this library is distributed.
  *
- * $Id: libDebug.c,v 1.3 2003/08/31 03:07:07 cosine Exp $
+ * $Id: libDebug.c,v 1.4 2004/09/18 03:41:15 pa33 Exp $
  */
 
 #include <stdio.h>
@@ -78,9 +78,17 @@ termDebug(struct debugWorkspace *ws)
   if (ws->path)
     free(ws->path);
 
+  if (ws->args)
+    free(ws->args);
+
+  if (ws->argsLinear)
+    free(ws->argsLinear);
+
   if (ws->fpuState)
     free(ws->fpuState);
 
+  clearBreakpoints(ws);
+
   free(ws);
 } /* termDebug() */
 
@@ -227,10 +235,16 @@ setArgsDebug(struct debugWorkspace *ws, char *args)
   size_t len;
 
   if (ws->args)
+  {
     free(ws->args);
+    ws->args = NULL;
+  }
 
   if (ws->argsLinear)
+  {
     free(ws->argsLinear);
+    ws->argsLinear = NULL;
+  }
 
   /*
    * We cannot trust the given buffer for use with SplitArgs(),
@@ -523,8 +537,8 @@ Side effects: upon success, memory is allocated for 'buf', so it
 */
 
 long
-dumpMemoryDebug(struct debugWorkspace *ws, char **buf,
-                unsigned long start, long bytes)
+dumpMemoryDebug(struct debugWorkspace *ws, unsigned char **buf,
+                unsigned long start, unsigned long bytes)
 
 {
   return (x86dumpMemoryDebug(ws, buf, start, bytes));
