@@ -8,25 +8,32 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: fmt_elf.h,v 1.1.1.1 2003/08/14 03:28:51 cosine Exp $
+ * $Id: fmt_elf.h,v 1.3 2004/10/09 17:26:54 pa33 Exp $
  */
 
-#ifndef INCLUDED_fmt_elf_h
-#define INCLUDED_fmt_elf_h
+#ifndef INCLUDED_libOFF_fmt_elf_h
+#define INCLUDED_libOFF_fmt_elf_h
 
 #ifndef INCLUDED_sys_types_h
 #include <sys/types.h>
 #define INCLUDED_sys_types_h
 #endif
 
-#ifndef INCLUDED_cfgOFF_h
-#include "cfgOFF.h"        /* uint* */
-#define INCLUDED_cfgOFF_h
+#ifndef INCLUDED_api_cfgOFF_h
+#include "api_cfgOFF.h"        /* uint* */
+#define INCLUDED_api_cfgOFF_h
 #endif
 
-#ifndef INCLUDED_symbols_h
+#ifdef HAVE_INTTYPES_H
+# ifndef INCLUDED_inttypes_h
+# include <inttypes.h>     /* uint* */
+# define INCLUDED_inttypes_h
+# endif
+#endif /* HAVE_INTTYPES_H */
+
+#ifndef INCLUDED_libOFF_symbols_h
 #include "symbols.h"       /* struct symbolWorkspace */
-#define INCLUDED_symbols_h
+#define INCLUDED_libOFF_symbols_h
 #endif
 
 typedef uint16_t Elf32_Half;
@@ -396,6 +403,7 @@ struct elfSymbolInfo
   char *name;
   unsigned int address;
   unsigned int offset;
+  unsigned int size;
 };
 
 /*
@@ -450,4 +458,4 @@ void printSymbolsELF(struct elfWorkspace *ws, char *symname,
                      void (*callback)(void *, const char *, ...),
                      void *args);
 
-#endif /* INCLUDED_fmt_elf_h */
+#endif /* INCLUDED_libOFF_fmt_elf_h */
