@@ -8,11 +8,11 @@
  * do so under the terms of the GNU General Public License under which
  * this library is distributed.
  *
- * $Id: symbols.h,v 1.1.1.1 2003/08/14 03:28:51 cosine Exp $
+ * $Id: symbols.h,v 1.1.1.1 2004/04/26 00:40:38 pa33 Exp $
  */
 
-#ifndef INCLUDED_symbols_h
-#define INCLUDED_symbols_h
+#ifndef INCLUDED_libOFF_symbols_h
+#define INCLUDED_libOFF_symbols_h
 
 struct aSymbol
 {
@@ -46,4 +46,4 @@ void *traverseSYM(struct symbolWorkspace *ws,
                   void *param);
 void unloadSYM(struct symbolWorkspace *ws);
 
-#endif /* INCLUDED_symbols_h */
+#endif /* INCLUDED_libOFF_symbols_h */
