@@ -1,14 +1,18 @@
 /*
  * libString
  *
- * Copyright (C) 1999 Patrick Alken
+ * Copyright (C) 1999-2004 Patrick Alken
  * This library comes with absolutely NO WARRANTY
  *
  * Should you choose to use and/or modify this source code, please
  * do so under the terms of the GNU General Public License under which
  * this library is distributed.
  *
- * $Id: version.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
+ * $Id: version.c,v 1.2 2004/10/09 23:08:03 pa33 Exp $
  */
 
-char libStringVersion[] = "1.0.0";
+#ifdef VERSION
+char libStringVersion[] = VERSION;
+#else
+char libStringVersion[] = "";
+#endif
