@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: c_continue.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
+ * $Id: c_continue.c,v 1.1.1.1 2004/04/26 00:40:49 pa33 Exp $
  */
 
 #include <errno.h>
@@ -45,25 +45,19 @@ c_continue(struct aldWorkspace *ws, int ac, char **av)
   int data,
       ret;
 
-  if (ModeConsole)
-  {
-    /*
-     * Restore the child's terminal state
-     */
-    restoreTerminal(&(ws->terminalWorkspace_p->ChildAttributes));
-  }
+  /*
+   * Restore the child's terminal state
+   */
+  restoreTerminal(&(ws->terminalWorkspace_p->ChildAttributes));
 
   ret = continueDebug(ws->debugWorkspace_p, &data);
 
-  if (ModeConsole)
-  {
-    /*
-     * Save the child's terminal state and restore the original
-     * terminal settings in case the child messed with them.
-     */
-    saveTerminal(&(ws->terminalWorkspace_p->ChildAttributes));
-    restoreTerminal(&(ws->terminalWorkspace_p->ParentAttributes));
-  }
+  /*
+   * Save the child's terminal state and restore the original
+   * terminal settings in case the child messed with them.
+   */
+  saveTerminal(&(ws->terminalWorkspace_p->ChildAttributes));
+  restoreTerminal(&(ws->terminalWorkspace_p->ParentAttributes));
 
   if (analyzeTraceResult(ws, ret, data) == 0)
     return (0);
