@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: c_disassemble.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
+ * $Id: c_disassemble.c,v 1.2 2004/09/11 05:17:16 pa33 Exp $
  */
 
 #include <stdlib.h>
@@ -23,9 +23,7 @@
 #include "load.h"
 #include "main.h"
 #include "msg.h"
-#include "scroll.h"
 #include "print.h"
-#include "window.h"
 
 #include "libDebug.h"
 #include "libOFF.h"
@@ -33,7 +31,6 @@
 /*
  * libString includes
  */
-#include "alloc.h"
 #include "Strn.h"
 
 static void ResetDisassemblyPosition(struct aldWorkspace *ws);
@@ -166,16 +163,6 @@ c_disassemble(struct aldWorkspace *ws, int ac, char **av)
       section,
       start,
       end);
-
-  #ifdef USE_CURSES
-
-    /*
-     * Clear any disassembly data from previous runs
-     */
-    if (ModeCurses)
-      ClearScrollData(DisassemblyFrame);
-
-  #endif /* USE_CURSES */
   } /* if (section) */
 
   membuf = 0;
@@ -212,7 +199,7 @@ c_disassemble(struct aldWorkspace *ws, int ac, char **av)
     numbytes += 15;
 
     ndumped = dumpMemoryDebug(ws->debugWorkspace_p,
-                              (char **) &membuf,
+                              &membuf,
                               start,
                               numbytes);
 
@@ -225,7 +212,7 @@ c_disassemble(struct aldWorkspace *ws, int ac, char **av)
             strerror(errno));
 
       if (membuf)
-        MyFree(membuf);
+        free(membuf);
 
       return (0);
     }
@@ -347,7 +334,7 @@ c_disassemble(struct aldWorkspace *ws, int ac, char **av)
 
   if (membuf)
   {
-    MyFree(membuf);
+    free(membuf);
     if (ndumped < numbytes)
     {
       Print(ws,
@@ -358,22 +345,6 @@ c_disassemble(struct aldWorkspace *ws, int ac, char **av)
     }
   }
 
-#ifdef USE_CURSES
-
-  if (ModeCurses)
-  {
-    /*
-     * The above Print() statements did not actually output
-     * anything to the window - they simply stored the data in
-     * the dynamic pointer array DisassemblyFrame->data. We need
-     * to do it this way so we can write the data now with the
-     * top line highlighted, which DrawWindow() will take care of.
-     */
-    DrawWindow(DisassemblyFrame);
-  }
-
-#endif /* USE_CURSES */
-
   return (1);
 } /* c_disassemble() */
 
@@ -394,14 +365,4 @@ ResetDisassemblyPosition(struct aldWorkspace *ws)
 
   ws->virtualObjectFileOffset = ws->virtualEntryPoint;
   ws->objectFileOffset = ws->entryPoint;
-
-#ifdef USE_CURSES
-
-  /*
-   * Clear any disassembly data from previous runs
-   */
-  if (ModeCurses)
-    ClearScrollData(DisassemblyFrame);
-
-#endif /* USE_CURSES */
 } /* ResetDisassemblyPosition() */
