@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: c_examine.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
+ * $Id: c_examine.c,v 1.3 2004/09/11 05:17:16 pa33 Exp $
  */
 
 #include <stdlib.h>
@@ -17,6 +17,7 @@
 
 #include "alddefs.h"
 #include "defs.h"
+#include "list.h"
 #include "load.h"
 #include "main.h"
 #include "memory.h"
@@ -28,7 +29,6 @@
 /*
  * libString includes
  */
-#include "alloc.h"
 #include "Strn.h"
 
 /*
@@ -62,14 +62,15 @@ c_examine(struct aldWorkspace *ws, int ac, char **av)
   unsigned long startaddr, /* address to begin memory dump */
                 stopaddr;  /* address to stop memory dump */
   int gotaddr;             /* did user supply start address? */
-  long elnum,              /* number of elements in memory to dump */
-       elsize,             /* size of each element */
-       elbytes;            /* number of bytes for all elements */
+  unsigned long elnum;     /* number of elements in memory to dump */
+  unsigned long elsize,    /* size of each element */
+                elbytes;   /* number of bytes for all elements */
   unsigned char output;    /* output type (hex, binary, etc) */
   unsigned char *membuf;   /* where to store dumped memory */
-  long numbytes;           /* number of bytes of memory to dump */
+  unsigned long numbytes;  /* number of bytes of memory to dump */
   long ndumped;            /* number of bytes actually dumped */
   unsigned long deladdr;   /* delta address (stopaddr - startaddr) */
+  struct genericList *ptr;
 
   /*
    * Defaults: dump 64 elements, each 1 byte, in hex format
@@ -93,8 +94,8 @@ c_examine(struct aldWorkspace *ws, int ac, char **av)
         return (0);
       }
 
-      elnum = strtol(av[cnt], &endptr, 0);
-      if ((endptr == av[cnt]) || (*endptr != '\0') || (elnum <= 0))
+      elnum = strtoul(av[cnt], &endptr, 0);
+      if ((endptr == av[cnt]) || (*endptr != '\0'))
       {
         Print(ws, P_ERROR, "Invalid element number: %s", av[cnt]);
         return (0);
@@ -139,7 +140,10 @@ c_examine(struct aldWorkspace *ws, int ac, char **av)
 
         if ((endptr == av[cnt]) || (*endptr != '\0'))
         {
-          int ridx;
+          int ret;
+          int sret;
+          struct offSectionInfo secInfo;
+          struct offSymbolInfo symInfo;
 
           /*
            * It is not a valid numerical address, but they
@@ -147,15 +151,49 @@ c_examine(struct aldWorkspace *ws, int ac, char **av)
            * start the dump at the address in the register
            * so check for that before giving an error
            */
-          ridx = findRegisterDebug(ws->debugWorkspace_p, av[cnt]);
-          if (ridx != (-1))
-            startaddr = (unsigned long) readRegisterDebug(ws->debugWorkspace_p, ridx);
+          ret = findRegisterDebug(ws->debugWorkspace_p, av[cnt]);
+          if (ret != (-1))
+          {
+            startaddr = (unsigned long)
+                         readRegisterDebug(ws->debugWorkspace_p,
+                                           ret);
+          }
           else
           {
-            Print(ws, P_ERROR, "Invalid address: %s", av[cnt]);
-            return (0);
+            /*
+             * Maybe it is a section name
+             */
+            sret = findSectionOFF(ws->offWorkspace_p,
+                                  av[cnt],
+                                  0,
+                                  &secInfo);
+            if (sret)
+            {
+              startaddr = (unsigned long) secInfo.address;
+              elnum = secInfo.size;
+            }
+            else
+            {
+              /*
+               * Maybe it is a symbol name
+               */
+              sret = findSymbolOFF(ws->offWorkspace_p,
+                                   av[cnt],
+                                   0,
+                                   &symInfo);
+              if (sret)
+              {
+                startaddr = (unsigned long) symInfo.address;
+                elnum = symInfo.size;
+              }
+              else
+              {
+                Print(ws, P_ERROR, "Invalid address: %s", av[cnt]);
+                return (0);
+              }
+            }
           }
-        }
+        } /* if (!gotaddr) */
       }
       else
       {
@@ -191,30 +229,59 @@ c_examine(struct aldWorkspace *ws, int ac, char **av)
    * dump
    */
   elbytes = elnum * elsize;
+
+  if (elbytes < elnum)
+  {
+    /* integer overflow occurred */
+    Print(ws,
+          P_ERROR,
+          "error: integer overflow");
+    return (0);
+  }
+
   if (stopaddr >= startaddr)
     deladdr = stopaddr - startaddr;
   else
     deladdr = 0;
 
-  if (deladdr > (unsigned long) elbytes)
+  if (deladdr > elbytes)
     numbytes = deladdr;
   else
     numbytes = elbytes;
 
   ndumped = dumpMemoryDebug(ws->debugWorkspace_p,
-                            (char **) &membuf,
+                            &membuf,
                             startaddr,
                             numbytes);
 
   if (membuf)
   {
+    /*
+     * OutputMemory uses print bursts, so if the user kills
+     * the burst before it completes, the following free()
+     * will not be called. So add 'membuf' to the list of
+     * items to be freed, in case longjmp() is called.
+     * After the setjmp() statement in procCommand, the
+     * 'toBeFreed' list will be freed.
+     */
+    ptr = insertList(&(ws->toBeFreed), (void *) membuf);
+
     if (ndumped > 0)
       OutputMemory(ws, membuf, startaddr, ndumped, elsize, output);
-    MyFree(membuf);
+
+    free(membuf);
+
+    deleteList(&(ws->toBeFreed), ptr);
   }
 
-  if (ndumped < numbytes)
-    Print(ws, P_ERROR, MSG_NOACCESS, startaddr + ndumped, strerror(errno));
+  if ((unsigned long) ndumped < numbytes)
+  {
+    Print(ws,
+          P_ERROR,
+          MSG_NOACCESS,
+          startaddr + ndumped,
+          strerror(errno));
+  }
 
   return (1);
 } /* c_examine() */
