@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: c_load.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
+ * $Id: c_load.c,v 1.1.1.1 2004/04/26 00:40:41 pa33 Exp $
  */
 
 #include "load.h"
@@ -37,7 +37,7 @@ c_load(struct aldWorkspace *ws, int ac, char **av)
 
   loadFile(ws, av[1]);
 
-  startDebug(ws->debugWorkspace_p, av[1], ModeCurses);
+  startDebug(ws->debugWorkspace_p, av[1], 0);
 
   awSetFileLoaded(ws);
 
