@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: c_next.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
+ * $Id: c_next.c,v 1.2 2004/10/10 03:07:56 pa33 Exp $
  */
 
 #include <stdlib.h>
@@ -18,6 +18,7 @@
 
 #include "alddefs.h"
 #include "disassemble.h"
+#include "display.h"
 #include "load.h"
 #include "main.h"
 #include "misc.h"
@@ -65,48 +66,30 @@ c_next(struct aldWorkspace *ws, int ac, char **av)
   else
     num = 1;
 
-  if (ModeConsole)
-  {
-    /*
-     * Restore the child's terminal state
-     */
-    restoreTerminal(&(ws->terminalWorkspace_p->ChildAttributes));
-  }
+  /*
+   * Restore the child's terminal state
+   */
+  restoreTerminal(&(ws->terminalWorkspace_p->ChildAttributes));
   
   ret = stepOverDebug(ws->debugWorkspace_p, num, &data);
 
-  if (ModeConsole)
-  {
-    /*
-     * Save the child's terminal state and restore the original
-     * terminal settings in case the child messed with them.
-     */
-    saveTerminal(&(ws->terminalWorkspace_p->ChildAttributes));
-    restoreTerminal(&(ws->terminalWorkspace_p->ParentAttributes));
-  }
+  /*
+   * Save the child's terminal state and restore the original
+   * terminal settings in case the child messed with them.
+   */
+  saveTerminal(&(ws->terminalWorkspace_p->ChildAttributes));
+  restoreTerminal(&(ws->terminalWorkspace_p->ParentAttributes));
 
   if (analyzeTraceResult(ws, ret, data) == 0)
     return (0);
 
 #if 0
-  if (IsSetStepDisplayRegs(ws))
-  {
-    /*
-     * Update and display new register values
-     */
-    displayRegisters(ws, NOREG, 1, DB_REGFL_DISPLAY_GENERAL);
-  }
-
-  if (IsSetStepDisplayFpRegs(ws))
-    displayRegisters(ws, NOREG, 1, DB_REGFL_DISPLAY_FPREGS);
-
-  if (IsSetStepDisplayMmxRegs(ws))
-    displayRegisters(ws, NOREG, 1, DB_REGFL_DISPLAY_MMXREGS);
-#endif
-
   displayRegisters(ws, NOREG, 1, ws->stepDisplayFlags);
 
   DisplayNextInstruction(ws);
+#endif
+
+  doStepDisplay(ws);
 
   return (1);
 } /* c_next() */
