@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: command.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
+ * $Id: command.c,v 1.4 2004/10/10 05:29:50 pa33 Exp $
  */
 
 #include <stdio.h>
@@ -23,6 +23,7 @@
 #include "command.h"
 #include "defs.h"
 #include "input.h"
+#include "list.h"
 #include "load.h"
 #include "main.h"
 #include "misc.h"
@@ -31,8 +32,6 @@
 #include "readln.h"
 #include "signals.h"
 #include "terminal.h"
-#include "wgets.h"
-#include "window.h"
 
 /*
  * libString includes
@@ -42,6 +41,12 @@
 
 static int ProcessCommand(struct aldWorkspace *main_p, char *command);
 
+/*
+ * Global: pointer to command parser environment. This needs to
+ * be global because SigHandler() needs it.
+ */
+jmp_buf            *CmdParserEnvPtr = 0;
+
 static struct Command mainCmds[] = {
   /*
    * Aliases - put these at the top since they are used
@@ -56,12 +61,13 @@ static struct Command mainCmds[] = {
 
   { "attach", c_attach, C_PTRACE },
   { "break", c_break, C_PROCESS },
-  { "clear", c_clear, C_CURSES },
   { "continue", c_continue, C_PROCESS|C_PTRACE },
-  { "delete", c_delete, 0 },
+  { "dbreak", c_dbreak, 0 },
+  { "delete", c_dbreak, C_ALIAS },
   { "detach", c_detach, C_PTRACE },
   { "disable", c_disable, 0 },
   { "disassemble", c_disassemble, C_FILELOADED },
+  { "display", c_display, C_PROCESS },
   { "dump", c_examine, C_ALIAS|C_PROCESS },
   { "enable", c_enable, 0 },
   { "enter", c_enter, C_PROCESS },
@@ -71,6 +77,7 @@ static struct Command mainCmds[] = {
   { "help", c_help, 0 },
   { "ignore", c_ignore, 0 },
   { "lbreak", c_lbreak, 0 },
+  { "ldisplay", c_ldisplay, C_PROCESS },
   { "load", c_load, 0 },
   { "next", c_next, C_PROCESS|C_PTRACE },
   { "quit", c_quit, 0 },
@@ -80,9 +87,8 @@ static struct Command mainCmds[] = {
   { "step", c_step, C_PROCESS|C_PTRACE },
   { "store", c_enter, C_ALIAS|C_PROCESS },
   { "tbreak", c_tbreak, C_PROCESS },
+  { "undisplay", c_undisplay, C_PROCESS },
   { "unload", c_unload, C_FILELOADED },
-  { "window", c_window, C_CURSES },
-  { "write", c_write, C_CURSES },
 
   { 0, 0, 0 }
 };
@@ -153,93 +159,76 @@ procCommand(struct aldWorkspace *ws)
   char last[MAXLINE + 1]; /* last command entered */
   char *bufptr,
        *cmdptr;
-  int GotLongJmp;
+  int GotLongJmp;         /* did we get called from longjmp()? */
   int ret;
+  struct genericList *lptr;
 
   *last = '\0';
   ret = 1;
 
-  if (ModeConsole)
+  while (ret >= 0)
   {
-    while (ret >= 0)
+    GotLongJmp = setjmp(command_p->CmdParserEnv);
+    if (GotLongJmp)
     {
-      GotLongJmp = setjmp(command_p->CmdParserEnv);
-      if (GotLongJmp)
-      {
-        /*
-         * In case we were in the middle of a print burst and the
-         * user ^C'd, clear the burst flag
-         */
-        endPrintBurst(ws->printWorkspace_p);
+      /*
+       * In case we were in the middle of a print burst and the
+       * user ^C'd, clear the burst flag
+       */
+      endPrintBurst(ws->printWorkspace_p);
 
-        restoreTerminal(&(ws->terminalWorkspace_p->ParentAttributes));
-        if (ModeConsole)
-          printf("\n");
-      }
+      restoreTerminal(&(ws->terminalWorkspace_p->ParentAttributes));
+      printf("\n");
 
       /*
-       * Read a line from stdin
+       * If there was any temporary memory allocated before the
+       * print burst, free it now
        */
-      bufptr = ReadLine(ws);
-      assert(bufptr != 0);
+      freeList(&(ws->toBeFreed));
+    }
 
-      if ((*bufptr == '\0') || (*bufptr == '\n'))
-      {
-        /*
-         * Use the last command entered - put 'last' back into
-         * 'buffer' so it doesn't get destroyed by ProcessCommand()
-         */
-        strncpy(buffer, last, MAXLINE);
-        cmdptr = buffer;
-      }
-      else
-      {
-        /*
-         * Save this command for later use
-         */
-        strncpy(last, bufptr, MAXLINE);
-        last[MAXLINE] = '\0';
-        cmdptr = bufptr;
-      }
+    /*
+     * Read a line from stdin
+     */
+    bufptr = ReadLine(ws);
+    assert(bufptr != 0);
 
+    if ((*bufptr == '\0') || (*bufptr == '\n'))
+    {
       /*
-       * Process given command
+       * Use the last command entered - put 'last' back into
+       * 'buffer' so it doesn't get destroyed by ProcessCommand()
        */
-      ret = ProcessCommand(ws, cmdptr);
+      strncpy(buffer, last, MAXLINE);
+      cmdptr = buffer;
+    }
+    else
+    {
+      /*
+       * Save this command for later use
+       */
+      strncpy(last, bufptr, MAXLINE);
+      last[MAXLINE] = '\0';
+      cmdptr = bufptr;
+    }
 
-      FreeLine(bufptr);
-    } /* while (ret >= 0) */
-  }
+    lptr = insertList(&(ws->toBeFreed), (void *) bufptr);
+
+    /*
+     * Process given command
+     */
+    ret = ProcessCommand(ws, cmdptr);
+
+    FreeLine(bufptr);
+
+    deleteList(&(ws->toBeFreed), lptr);
+  } /* while (ret >= 0) */
 
   /*
-   * If we get here, a fatal error occured
+   * If we get here, a fatal error occured, or the user
+   * quit the program.
    */
   return (0);
-
-#ifdef USE_CURSES
-
-  if (ModeCurses)
-  {
-    assert(CurrentFrame != 0);
-
-    while (1)
-    {
-      /*DisplayPrompt();*/
-
-      RefreshFrames();
-
-      wGets(CurrentFrame->window, buffer, MAXLINE);
-
-      if (*buffer)
-      {
-        AddInput(buffer);
-        ProcessCommand(ws, buffer);
-      }
-    }
-  } /* if (ModeCurses) */
-
-#endif /* USE_CURSES */
-
 } /* procCommand() */
 
 /*
@@ -263,6 +252,7 @@ ProcessCommand(struct aldWorkspace *ws, char *command)
   struct Command *cptr;
   unsigned int flags;
   int ret;
+  struct genericList *lptr;
 
   assert(command != 0);
 
@@ -288,56 +278,47 @@ ProcessCommand(struct aldWorkspace *ws, char *command)
     }
     else
     {
-      Print(ws, P_ERROR, "Unknown command: %s (help shows a list)", av[0]);
+      Print(ws,
+            P_ERROR,
+            "Unknown command: %s (help shows a list)",
+            av[0]);
     }
 
-    MyFree(av);
+    free(av);
     return (0);
   }
 
   if ((cptr->flags & C_FILELOADED) && !awIsFileLoaded(ws))
   {
     Print(ws, P_ERROR, MSG_NOFILELOADED);
-    MyFree(av);
+    free(av);
     return (0);
   }
 
-  if ((cptr->flags & C_PROCESS) && !awIsAttached(ws) && !awIsFileLoaded(ws))
+  if ((cptr->flags & C_PROCESS) && !awIsAttached(ws) &&
+      !awIsFileLoaded(ws))
   {
     /*
      * This command requires a ptraced process, but there are none
      * currently
      */
     Print(ws, P_ERROR, MSG_NOPROCESS);
-    MyFree(av);
+    free(av);
     return (0);
   }
 
-  if ((cptr->flags & C_PROCESS_RUNNING) && !isRunningDebug(ws->debugWorkspace_p))
+  if ((cptr->flags & C_PROCESS_RUNNING) &&
+      !isRunningDebug(ws->debugWorkspace_p))
   {
     /*
-     * This command requires the process to be running, but it has not been
-     * executed yet
+     * This command requires the process to be running, but it
+     * has not been executed yet
      */
     Print(ws, P_ERROR, MSG_NOPROCESS);
-    MyFree(av);
+    free(av);
     return (0);
   }
 
-#ifdef USE_CURSES
-
-  if (!ModeCurses && (cptr->flags & C_CURSES))
-  {
-    Print(ws,
-          P_ERROR,
-          "The command \"%s\" works only in curses mode",
-          cptr->cmd);
-    MyFree(av);
-    return (0);
-  }
-
-#endif /* USE_CURSES */
-
   if (cptr->flags & C_PTRACE)
   {
     /*
@@ -363,12 +344,27 @@ ProcessCommand(struct aldWorkspace *ws, char *command)
     signal(SIGINT, SigHandler);
   }
 
+  /*
+   * The command we execute may do print bursts, and the user
+   * may stop the burst before it completes, meaning the following
+   * free(av) won't be executed. So add 'av' to our list of to
+   * be freed items to make sure it is freed in case we do a
+   * longjmp().
+   */
+  lptr = insertList(&(ws->toBeFreed), (void *) av);
+
   /*
    * Execute the command
    */
   ret = (*cptr->funcptr)(ws, ac, av);
 
-  MyFree(av);
+  free(av);
+
+  /*
+   * If we get here, no longjmp() was issued, so 'av' was
+   * freed normally. Remove it from the to be freed list.
+   */
+  deleteList(&(ws->toBeFreed), lptr);
 
   if (ret < 0)
     return (ret);
