@@ -1,14 +1,14 @@
 /*
  * Assembly Language Debugger
  *
- * Copyright (C) 2000 Patrick Alken
+ * Copyright (C) 2000-2004 Patrick Alken
  * This program comes with absolutely NO WARRANTY
  *
  * Should you choose to use and/or modify this source code, please
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: help.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
+ * $Id: help.c,v 1.3 2004/10/10 05:29:50 pa33 Exp $
  */
 
 #include <stdio.h>
@@ -38,14 +38,6 @@ static struct HelpCmd GeneralHelp[] = {
 \n\
 <pid> - process id to attach to",
   },
-  {
-    "clear",
-    "Clears specified window",
-    "[number]\n\
-\n\
-[number] - Optional window number (if not given, current window\n\
-           is cleared)",
-  },
   {
     "continue",
     "Continue execution of debugged process",
@@ -87,6 +79,30 @@ The output of this command is as follows:\n\
 unless a start/stop memory address is given.\n\
 \n\
 Alias: d",
+  },
+  {
+    "display",
+    "Display memory after single steps",
+    "[start]|[register]|[section]|[symbol] [stop] [-num <num>] [-size <value>] [-output <letter>]\n\
+\n\
+[start]            - Memory address to start from\n\
+[register]         - Memory dump begins at register contents\n\
+[section]          - Memory dump begins at section start\n\
+[symbol]           - Memory dump begins at symbol start\n\
+[stop]             - Memory address to stop dump\n\
+[-num <num>]       - Number of elements to dump (default: 20)\n\
+[-size <value>]    - Size of each element in bytes (default: 1)\n\
+[-output <letter>] - Output format for each element (default: x)\n\
+  'x' = hexadecimal\n\
+  'o' = octal\n\
+  'd' = decimal\n\
+\n\
+Example:\n\
+  display -n 50 -s 1 -o x 0xABCD\n\
+   After each single step, 50 bytes of memory starting at location\n\
+   0xABCD will be printed.\n\
+\n\
+See also: ldisplay, undisplay"
   },
   {
     "enter",
@@ -104,9 +120,12 @@ Alias: store",
   {
     "examine",
     "Examine the contents of the program's memory",
-    "[start] [stop] [-num <num>] [-size <value>] [-output <letter>]\n\
+    "[start]|[register]|[section]|[symbol] [stop] [-num <num>] [-size <value>] [-output <letter>]\n\
 \n\
-[start | register] - Memory address to start from\n\
+[start]            - Memory address to start from\n\
+[register]         - Memory dump begins at register contents\n\
+[section]          - Memory dump begins at section start\n\
+[symbol]           - Memory dump begins at symbol start\n\
 [stop]             - Memory address to stop dump\n\
 [-num <num>]       - Number of elements to dump (default: 20)\n\
 [-size <value>]    - Size of each element in bytes (default: 1)\n\
@@ -121,28 +140,36 @@ Example:\n\
    starting at location 0xABCD.\n\
 \n\
   If no starting address is given, the address specified in\n\
-\"set entry-point\" is used. A register name may be given in\n\
-place of a starting address, and the memory dump will begin\n\
-at the address given by the register's contents.\n\
+\"set entry-point\" is used. A register name, section name,\n\
+or symbol name may be given in place of a starting address.\n\
 \n\
 Aliases: e, dump",
   },
   {
     "file",
     "Outputs specified information on current file",
-    "<header | secinfo | symbols>\n\
+    "<header | secinfo | syminfo>\n\
 \n\
 header         - Output information about the file's object header\n\
 secinfo [name] - Output information about the file's sections. If\n\
                  [name] is given, output information about that\n\
                  specific section.\n\
-symbols        - Output information about the file's symbols, if any",
+syminfo [sym]  - Output information about the file's symbols, if any.\n\
+                 If [sym] is given, output information about that\n\
+                 specific symbol.",
   },
   {
     "help",
     "Displays commands, or gives specific help on commands",
     "[optional commands]",
   },
+  {
+    "ldisplay",
+    "Print list of memory addresses to be displayed after single stepping",
+    "\n\
+\n\
+See also: display, undisplay"
+  },
   {
     "load",
     "Loads a new file into memory for debugging",
@@ -214,26 +241,22 @@ Type \"help set <option>\" for more information on <option>",
 [num] - number of instructions to step through (default: 1)\n\
 \n\
 Alias: s",
+  },
+  {
+    "undisplay",
+    "Remove a display address",
+    "<number | all>\n\
+\n\
+  number - number (can be obtained from \"ldisplay\")\n\
+  all    - Delete all display addresses\n\
+\n\
+See also: display, ldisplay"
   },
   {
     "unload",
     "Unloads the current debug file from memory",
     "",
   },
-  {
-    "window",
-    "Perform window manipulation",
-    "[number]\n\
-\n\
-[number] - window number to switch to\n\
-\n\
- If no number is given, all windows and their numbers are listed.",
-  },
-  {
-    "write",
-    "Writes contents of current window to [filename]",
-    "[filename]",
-  },
 
   { 0, 0, 0 },
 };
@@ -256,12 +279,14 @@ static struct HelpCmd BreakHelp[] = {
               have been compiled with debugging symbols enabled.",
   },
   {
-    "delete",
+    "dbreak",
     "Delete a breakpoint",
     "<number | all>\n\
 \n\
   number - Breakpoint number (can be obtained from \"lbreak\")\n\
-  all    - Delete all breakpoints",
+  all    - Delete all breakpoints\n\
+\n\
+Alias: delete",
   },
   {
     "disable",
