@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: load.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
+ * $Id: load.c,v 1.2 2004/10/09 18:22:08 pa33 Exp $
  */
 
 #include <stdio.h>
@@ -32,7 +32,6 @@
 /*
  * libString includes
  */
-#include "alloc.h"
 #include "Strn.h"
 
 /*
@@ -61,6 +60,7 @@ loadFile(struct aldWorkspace *ws, char *filename)
   int ret;
   char buffer[MAXLINE];
   struct offParameters offParams;
+  unsigned long symcnt;
 
   assert(filename != 0);
 
@@ -158,7 +158,14 @@ loadFile(struct aldWorkspace *ws, char *filename)
     /*
      * Load any symbols
      */
-    loadSymbolsOFF(ws->offWorkspace_p);
+    RawPrint(ws, P_COMMAND, "Loading debugging symbols...");
+
+    symcnt = loadSymbolsOFF(ws->offWorkspace_p);
+
+    if (symcnt)
+      Print(ws, P_COMMAND, "(%lu symbols loaded)", symcnt);
+    else
+      Print(ws, P_COMMAND, "(no symbols found)");
 
     /*
      * Go to 32 bit mode
@@ -199,7 +206,7 @@ unloadFile(struct aldWorkspace *ws)
   ws->objectFileDescriptor = (-1);
 
   if (ws->objectFileName)
-    MyFree(ws->objectFileName);
+    free(ws->objectFileName);
 
   ws->MapPtr = 0;
 
@@ -207,47 +214,3 @@ unloadFile(struct aldWorkspace *ws)
 
   unloadSymbolsOFF(ws->offWorkspace_p);
 } /* unloadFile() */
-
-#if 0
-
-/*
-IdentifyFileType()
- Attempt to identify the object format of 'filename'
-
-Return: OT_xxx if match found
-        OT_UNKNOWN if no match found
-*/
-
-static int
-IdentifyFileType(struct loadWorkspace *ws, char *filename)
-
-{
-  struct aoutParameters aoutParams;
-  struct elfParameters elfParams;
-
-  assert(filename != 0);
-
-  if (checkAout(ws->aoutWorkspace_p, filename, ws->MapPtr, ws->MappedSize, &aoutParams))
-  {
-    ws->params.virtualEntryPoint = aoutParams.virtualEntryPoint;
-    ws->params.entryPoint = aoutParams.entryPoint;
-
-    return (OT_AOUT);
-  }
-
-  if (checkElf(ws->elfWorkspace_p, filename, ws->MapPtr, ws->MappedSize, &elfParams))
-  {
-    ws->params.virtualFileAddress = elfParams.virtualFileAddress;
-    ws->params.virtualEntryPoint = elfParams.virtualEntryPoint;
-    ws->params.entryPoint = elfParams.entryPoint;
-
-    /* XXX - put this somewhere else */
-    flagsDisasm(mainWorkspace_p->disasmWorkspace_p, DA_32BITMODE);
-
-    return (OT_ELF);
-  }
-
-  return (OT_UNKNOWN);
-} /* IdentifyFileType() */
-
-#endif /* 0 */
