@@ -1,14 +1,14 @@
 /*
  * Assembly Language Debugger
  *
- * Copyright (C) 2000-2003 Patrick Alken
+ * Copyright (C) 2000-2004 Patrick Alken
  * This program comes with absolutely NO WARRANTY
  *
  * Should you choose to use and/or modify this source code, please
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: main.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
+ * $Id: main.c,v 1.2 2004/04/26 03:39:32 pa33 Exp $
  */
 
 #include <stdio.h>
@@ -26,7 +26,6 @@
 #include "signals.h"
 #include "terminal.h"
 #include "version.h"
-#include "window.h"
 
 #include "libDebug.h"
 #include "libDASM.h"
@@ -40,25 +39,6 @@
 static int ParseCommandLine(struct aldWorkspace *ws, int ac, char *av[],
                             char **filename);
 
-extern char libDebugVersion[];
-extern char libDASMVersion[];
-extern char libOFFVersion[];
-
-/*
- * Global: run in console mode
- */
-int                  ModeConsole = 0;
-
-/*
- * Global: run in curses mode
- */
-int                  ModeCurses = 0;
-
-/*
- * Global: Endian type of machine we are running on
- */
-int                  PlatformEndian = 0;
-
 /*
 ParseCommandLine()
  Parse command line arguments
@@ -94,7 +74,6 @@ ParseCommandLine(struct aldWorkspace *ws, int ac, char *av[], char **filename)
 \n\
 Options:\n\
 \n\
-  -c          : Use curses display (if available)\n\
   -h          : Output this help screen\n\
   -v          : Output version information\n",
             av[0]);
@@ -129,15 +108,6 @@ Options:\n\
 
           break; /* not reached */
         } /* case 'v' */
-
-        /*
-         * Use curses
-         */
-        case 'c':
-        {
-          ModeCurses = 1;
-          break;
-        } /* case 'c' */
       }
     }
     else
@@ -149,9 +119,6 @@ Options:\n\
     }
   }
 
-  if (!ModeCurses)
-    ModeConsole = 1;
-
   return (1);
 } /* ParseCommandLine() */
 
@@ -171,11 +138,6 @@ initALD(int argc, char *argv[])
 {
   struct aldWorkspace *ws;
   char *filename;
-  union
-  {
-    long l;
-    char c[sizeof(long)];
-  } end_u;
 
   ws = (struct aldWorkspace *) malloc(sizeof(struct aldWorkspace));
   if (!ws)
@@ -188,18 +150,6 @@ initALD(int argc, char *argv[])
 
   ws->filename = 0;
 
-  ModeConsole = 0;
-  ModeCurses = 0;
-
-  /*
-   * Determine the endian type of this platform
-   */
-  end_u.l = 1;
-  if (end_u.c[sizeof(long) - 1] == 1)
-    PlatformEndian = ENDIANTYPE_BIG;
-  else
-    PlatformEndian = ENDIANTYPE_LITTLE;
-
   filename = 0;
   if (!ParseCommandLine(ws, argc, argv, &filename))
   {
@@ -222,6 +172,14 @@ initALD(int argc, char *argv[])
     return (0);
   }
 
+  /*
+   * It is unfortunate that we need this global variable,
+   * but we can't pass arbitary args to our signal handler,
+   * and SigHandler() needs this environment for the longjmp()
+   * call.
+   */
+  CmdParserEnvPtr = &(ws->commandWorkspace_p->CmdParserEnv);
+
   /*
    * Initialize print workspace
    */
@@ -278,29 +236,6 @@ initALD(int argc, char *argv[])
     return (0);
   }
 
-  if (ModeCurses)
-  {
-  #ifdef USE_CURSES
-
-    fprintf(stderr, "ncurses support is currently disabled until a future release\n");
-    exit(1);
-
-#if 0
-    if (!InitWindows())
-      exit(1);
-#endif
-
-  #else
-
-    fprintf(stderr,
-      "This binary was compiled without ncurses support\n");
-
-    termALD(ws);
-    return (0);
-
-  #endif /* !USE_CURSES */
-  }
-
   if (filename)
     ws->filename = filename;
 
@@ -345,6 +280,12 @@ termALD(struct aldWorkspace *ws)
       fprintf(stderr, "Detached from process id %d\n", dret);
   }
 
+  /*
+   * Unload current file if any
+   */
+  if (awIsFileLoaded(ws))
+    unloadFile(ws);
+
   if (ws->commandWorkspace_p)
     termCommand(ws->commandWorkspace_p);
 
@@ -387,19 +328,19 @@ procALD(struct aldWorkspace *ws)
     return (0);
 
   /*
-   * We will never get here
+   * A fatal error occured, or the user quit
    */
   return (1);
 } /* procALD() */
 
-struct aldWorkspace *mainWorkspace_p;
-
 int
 main(int argc, char *argv[])
 
 {
+  struct aldWorkspace *mainWorkspace_p;
+
   fprintf(stdout, "Assembly Language Debugger %s\n", aVersion);
-  fprintf(stdout, "Copyright (C) 2000-2003 Patrick Alken\n\n");
+  fprintf(stdout, "Copyright (C) 2000-2004 Patrick Alken\n\n");
 
   mainWorkspace_p = initALD(argc, argv);
   if (!mainWorkspace_p)
@@ -417,7 +358,9 @@ main(int argc, char *argv[])
   if (mainWorkspace_p->filename)
   {
     loadFile(mainWorkspace_p, mainWorkspace_p->filename);
-    startDebug(mainWorkspace_p->debugWorkspace_p, mainWorkspace_p->filename, ModeCurses);
+    startDebug(mainWorkspace_p->debugWorkspace_p,
+               mainWorkspace_p->filename,
+               0);
     awSetFileLoaded(mainWorkspace_p);
   }
 
@@ -425,8 +368,5 @@ main(int argc, char *argv[])
 
   termALD(mainWorkspace_p);
 
-  /*
-   * If procALD() returns, a fatal error occurred
-   */
   return (1);
 } /* main() */
