@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: memory.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
+ * $Id: memory.c,v 1.3 2004/07/21 16:36:06 pa33 Exp $
  */
 
 #include <stdlib.h>
@@ -118,17 +118,17 @@ g              8          giant (8 bytes)
     architecture we are running on
 */
 
-long
+unsigned long
 GetElementSize(char *str)
 
 {
-  long ret;
+  unsigned long ret;
   char *endptr;
   unsigned char c;
 
   assert(str != 0);
 
-  ret = strtol(str, &endptr, 0);
+  ret = strtoul(str, &endptr, 0);
   if ((endptr != str) && (*endptr == '\0'))
   {
     /*
@@ -271,8 +271,9 @@ Inputs: ws     - main workspace
 */
 
 void
-OutputMemory(struct aldWorkspace *ws, unsigned char *buf, unsigned long start,
-             long bytes, long size, unsigned char output)
+OutputMemory(struct aldWorkspace *ws, unsigned char *buf,
+             unsigned long start, long bytes, long size,
+             unsigned char output)
 
 {
   unsigned char *bufptr;
@@ -334,8 +335,7 @@ OutputMemory(struct aldWorkspace *ws, unsigned char *buf, unsigned long start,
        */
       Print(ws,
             P_ERROR,
-            "GetMemoryValue() failed for size %ld",
-            size);
+            "OutputMemory: currently only sizes of 1, 2, or 4 bytes are supported");
       endPrintBurst(ws->printWorkspace_p);
       return;
     }
