@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: misc.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
+ * $Id: misc.c,v 1.1.1.1 2004/04/26 00:40:49 pa33 Exp $
  */
 
 #include <ctype.h>
@@ -20,11 +20,6 @@
 #include "defs.h"
 #include "load.h"
 #include "main.h"
-#include "window.h"
-
-#ifdef USE_CURSES
-#include <ncurses.h>
-#endif
 
 /*
 endProcess()
