@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: registers.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
+ * $Id: registers.c,v 1.2 2004/10/09 17:47:15 pa33 Exp $
  */
 
 #include <stdio.h>
@@ -23,8 +23,6 @@
 #include "msg.h"
 #include "print.h"
 #include "registers.h"
-#include "scroll.h"
-#include "window.h"
 
 #include "libDebug.h"
 
@@ -169,7 +167,10 @@ displayRegsNormalCallback(struct debugRegisterInfo *regInfo, void *args)
   }
   else
   {
-    sprintf(cargs->scratch, "0x%0*lX", regInfo->size, regInfo->value);
+    sprintf(cargs->scratch,
+            "0x%0*lX",
+            regInfo->size << 1,
+            regInfo->value);
 
     Print(cargs->main_p,
           P_REGISTER,
@@ -246,7 +247,7 @@ displayRegsCompactCallback(struct debugRegisterInfo *regInfo, void *args)
              P_REGISTER,
              "%-3s = 0x%0*lX ",
              regInfo->name,
-             regInfo->size,
+             regInfo->size << 1,
              regInfo->value);
   }
 
