@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: set.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
+ * $Id: set.c,v 1.1.1.1 2004/04/26 00:40:42 pa33 Exp $
  */
 
 #include <stdlib.h>
@@ -29,17 +29,16 @@
 /*
  * libString includes
  */
-#include "alloc.h"
 #include "Strn.h"
 
-static int setArgs(struct aldWorkspace *ws, int ac, char **av, unsigned int pwin,
-                   char *str);
+static int setArgs(struct aldWorkspace *ws, int ac, char **av,
+                   unsigned int pwin, char *str);
 static int setDisasmShowSyms(struct aldWorkspace *ws, int ac, char **av,
                              unsigned int pwin, char *str);
-static int setEntryPoint(struct aldWorkspace *ws, int ac, char **av, unsigned int pwin,
-                         char *str);
-static int setFileOffset(struct aldWorkspace *ws, int ac, char **av, unsigned int pwin,
-                         char *str);
+static int setEntryPoint(struct aldWorkspace *ws, int ac, char **av,
+                         unsigned int pwin, char *str);
+static int setFileOffset(struct aldWorkspace *ws, int ac, char **av,
+                         unsigned int pwin, char *str);
 static int setOutput(struct aldWorkspace *ws, int ac, char **av, unsigned int pwin,
                      char *str);
 static int setPausePrint(struct aldWorkspace *ws, int ac, char **av, unsigned int pwin,
@@ -53,7 +52,7 @@ static int setStepDisplayFpRegs(struct aldWorkspace *ws, int ac, char **av,
 static int setStepDisplayMmxRegs(struct aldWorkspace *ws, int ac, char **av,
                                   unsigned int pwin, char *str);
 
-struct Command setCmds[] = {
+static struct Command setCmds[] = {
   { "args", setArgs, 0 },
   { "disasm-show-syms", setDisasmShowSyms, 0 },
   { "entry-point", setEntryPoint, 0 },
@@ -81,10 +80,6 @@ static char *setCmdsSyntax[] = {
   "set step-display-mmxregs <on | off>"   /* SETSYN_STEP_DISP_MMXREGS */
 };
 
-/*
- * List of setting variables and their default values
- */
-
 /*
 DisplaySettings()
   Output a list of all settings and their values
@@ -111,6 +106,22 @@ DisplaySettings(struct aldWorkspace *ws)
   }
 } /* DisplaySettings() */
 
+/*
+FindSetCommand()
+  Search for a set command name in the array 'setCmds'
+*/
+
+struct Command *
+FindSetCommand(char *name, unsigned int *flags)
+
+{
+  return (FindCommand(setCmds, name, flags));
+} /* FindSetCommand() */
+
+/*******************************************************
+ *                 INTERNAL ROUTINES                   *
+ *******************************************************/
+
 /*
 setArgs()
   Set the runtime arguments for the debugged process
@@ -385,7 +396,7 @@ setPrompt(struct aldWorkspace *ws, int ac, char **av, unsigned int pwin,
     return (1);
   }
 
-  MyFree(ws->commandWorkspace_p->CmdPrompt);
+  free(ws->commandWorkspace_p->CmdPrompt);
   ws->commandWorkspace_p->CmdPrompt = Strdup(av[2]);
 
   return (2);
