@@ -8,7 +8,7 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: terminal.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
+ * $Id: terminal.c,v 1.1.1.1 2004/04/26 00:40:47 pa33 Exp $
  */
 
 #include "defs.h"
@@ -19,10 +19,6 @@
 #include <errno.h>
 #include <string.h>
 
-#ifdef HAVE_CURSES_H
-#include <curses.h>
-#endif
-
 #ifdef HAVE_TERM_H
 #include <term.h>
 #endif
@@ -49,9 +45,6 @@ initTerminal()
 
 {
   struct terminalWorkspace *ws;
-#ifdef USE_CURSES
-  char *termtype;
-#endif
 
   ws = (struct terminalWorkspace *) malloc(sizeof(struct terminalWorkspace));
   if (!ws)
@@ -74,35 +67,6 @@ initTerminal()
   ws->LinesPerPage = 25;
   ws->ColsPerLine = 80;
 
-#ifdef USE_CURSES
-
-  termtype = getenv("TERM");
-  if (termtype)
-  {
-    /*
-     * 2048 should be large enough for all known terminals
-     */
-    char termbuf[2048];
-    int status;
-
-    status = tgetent(termbuf, termtype);
-    if (status > 0)
-    {
-      int lval,
-          cval;
-
-      lval = tgetnum("li");
-      if (lval >= 0)
-        ws->LinesPerPage = lval;
-
-      cval = tgetnum("co");
-      if (cval >= 0)
-        ws->ColsPerLine = cval;
-    }
-  }
-
-#endif /* USE_CURSES */
-
   if (!saveTerminal(&(ws->ParentAttributes)))
   {
     fprintf(stderr, "initTerminal: saveTerminal failed\n");
