@@ -8,12 +8,11 @@
  * do so under the terms of the GNU General Public License under which
  * this program is distributed.
  *
- * $Id: traceresult.c,v 1.1.1.1 2003/08/14 03:28:52 cosine Exp $
+ * $Id: traceresult.c,v 1.1.1.1 2004/04/26 00:40:41 pa33 Exp $
  */
 
 #include <errno.h>
 #include <string.h>
-#include <assert.h>
 
 #include "main.h"
 #include "misc.h"
@@ -23,10 +22,11 @@
 
 /*
 analyzeTraceResult()
-  This function is called after the commands {step, next, run, continue} have been
-executed. Each of these commands call a ptrace routine to perform a task, and these
-ptrace routines all return the same value depending upon what happens. So instead of
-duplicating switch statement for all of those commands, this is a common routine
+  This function is called after the commands {step, next, run,
+continue} have been executed. Each of these commands call a ptrace
+routine to perform a task, and these ptrace routines all return the
+same value depending upon what happens. So instead of duplicating
+switch statement for all of those commands, this is a common routine
 to analyze the return result and take appropriate action.
 
 Inputs: ws     - main workspace
@@ -34,7 +34,8 @@ Inputs: ws     - main workspace
         data   - possibly modified data
 
 Return: 1 if everything is normal
-        0 if an error occurred, or if the program terminated (due to a signal or normally)
+        0 if an error occurred, or if the program terminated (due to
+        a signal or normally)
 
 Note: if an error occurs, a message will be displayed
 */
@@ -76,14 +77,26 @@ analyzeTraceResult(struct aldWorkspace *ws, int result, int data)
       struct aSignal *sptr;
 
       sptr = GetSignal(data);
-      assert(sptr != 0);
-
-      Print(ws,
-            P_COMMAND,
-            MSG_GOTSIGNAL,
-            sptr->name,
-            sptr->desc,
-            getAddressDebug(ws->debugWorkspace_p));
+      if (sptr)
+      {
+        Print(ws,
+              P_COMMAND,
+              MSG_GOTSIGNAL,
+              sptr->name,
+              sptr->desc,
+              getAddressDebug(ws->debugWorkspace_p));
+      }
+      else
+      {
+        /*
+         * The program received an unknown signal
+         */
+        Print(ws,
+              P_COMMAND,
+              MSG_GOTUNKNOWNSIG,
+              data,
+              getAddressDebug(ws->debugWorkspace_p));
+      }
 
       break;
     }
@@ -143,13 +156,21 @@ analyzeTraceResult(struct aldWorkspace *ws, int result, int data)
       struct aSignal *sptr;
 
       sptr = GetSignal(data);
-      assert(sptr != 0);
-
-      Print(ws,
-            P_COMMAND,
-            MSG_PROGTERMSIG,
-            sptr->name,
-            sptr->desc);
+      if (sptr)
+      {
+        Print(ws,
+              P_COMMAND,
+              MSG_PROGTERMSIG,
+              sptr->name,
+              sptr->desc);
+      }
+      else
+      {
+        Print(ws,
+              P_COMMAND,
+              MSG_PROGTERMUNKNOWNSIG,
+              data);
+      }
 
       endProcess(ws);
 
